# Kaydet is Your Personal Terminal Diary

"kaydet" is a simple (112 lines if Python code) based diary app designed to
help you preserve your daily thoughts, experiences, and memories without 
leaving terminal.

# How to Install?

    $ pip3 install kaydet

# Key Features:

## Short Entries

Record your daily thoughts and experiences by typing them as a parameter in
the terminal. "kaydet" automatically saves your entry to a file dedicated to
the current day, along with a timestamp.

    $ kaydet "I am very good with my kids today :)"
    > Entry added to: /Users/mirat/.kaydet/2023-08-02.txt

## Long Entries

If you don't give any parameters to "kaydet" it opens your favourite text
editor to allow you to create long entries.

    $ kaydet

## Time-Stamped Entries

Each diary entry is precisely dated, ensuring your thoughts are organized
chronologically for easy navigation and reflection.

## Trustless

"kaydet" uses txt files to store your entries, guaranteeing your diary
remains private and secure on your own hard disk. You don't have to trust me,
or any company.

## Synch in Your Way

Do you want to synch your diary entries between your devices? You can use any
folder synchronization service that you trust.

## Customizable Settings

You can configure "kaydet" to your preferences with customizable options,
including file naming conventions, text editor that you want to use, entry
format.


